#
# BEGIN COPYRIGHT
# *************************************************************************
# Licensed Materials - Property of IBM
# 5724-L01, 5655-N53, 5724-I82, 5655-R15
# (C) Copyright IBM Corporation 2006. All rights reserved.
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
# *************************************************************************
# END COPYRIGHT

#
# The sample contained herein is provided to you "AS IS".
# It is furnished by IBM as a sample script


from java.io import FileInputStream, IOException
from java.util import Properties
from os.path import abspath, normpath, exists
import os
import sys
import java.lang.System

errorCode = ""
errorInfo = ""

#*******************************************************************************************************
# Procedure to delete Property
#*******************************************************************************************************
def deleteProperty ( inPropertyName,inScope ):

        property  = inPropertyName
        scope     = inScope

        nodeVarMapList = AdminConfig.getid(scope)

        if (len(nodeVarMapList) == 0):
                print "No VariableMap found for "+`scope`
                return
        #endIf

        for var in AdminConfig.list("VariableSubstitutionEntry", nodeVarMapList ).split(nl):
                symbolicName = AdminConfig.showAttribute(var, "symbolicName" )
                if (symbolicName == property):
                        AdminConfig.remove(var)
                        print "--------------------------------------------------------------------------"
                        print "Removing Variable: "+property + " from Scope: " + scope
                        return 0
                #endIf
        #endFor

        return 0
#endDef


#*******************************************************************************************************
# Modify 100Custom.xml to use WAS work manager
#*******************************************************************************************************
def modify100CustomXML ():
    customXMLText = '''\
<properties>
<event-manager merge="mergeChildren">
<scheduler>
<use-was-work-manager merge="replace">true</use-was-work-manager>
<was-work-manager merge="replace">wm/default</was-work-manager>
</scheduler>
</event-manager>
</properties>
'''

    userInstallRoot = java.lang.System.getProperty ( "user.install.root" )
    customXMLFile = userInstallRoot + "/config/cells/" + cellName + "/nodes/" + nodeName + "/servers/" + serverName + "/process-server/config/100Custom.xml"
    print "--------------------------------------------------------------------------"
    print "Modifying: " + customXMLFile

    f = open(customXMLFile, 'w')
    f.write (customXMLText)
    f.close()
#endDef

#*******************************************************************************************************
# Procedure to Obtain EndpointProperty  ProviderEndpoints
#*******************************************************************************************************

def syncNodes():

  nl = AdminConfig.list('Node').split(nl)
  for n in nl:
     nn = AdminConfig.showAttribute(n, 'name')
     objn = "type=NodeSync,node=" + nn + ",*"
     Syncl = AdminControl.completeObjectName(objn)
     if Syncl != "":
         AdminControl.invoke(Syncl, 'sync')
         print "Done with node " + nn
     else:
         print "Skipping node " + nn
     continue

#endDef

#*******************************************************************************************************
# MAIN
#*******************************************************************************************************

#
# Commandline parameter handling
#

serverName      = ""
nodeName        = ""
clusterName     = ""

cellName        = java.lang.System.getProperty ( "local.cell" )
hostc           = 'host'
portc           = 'port'
vhhostc         = 'hostname'

nl              = java.lang.System.getProperty("line.separator")

argc            = len(sys.argv)
display         = 0
sync            = 0
help            = 0


i = 0  #forStart
while ( i < argc ):  #forTest
        arg = sys.argv[i]

        if (arg == "-server"):
                i = i+1;
                if (i < argc):
                        serverName = sys.argv[i]
                else:
                        argerr = "Missing argument for '" + arg + "' parameter"
        elif (arg == "-node"):
                i = i+1;
                if (i < argc):
                        nodeName = sys.argv[i]
                else:
                        argerr = "Missing argument for '" + arg + "' parameter"
                #endElse
        elif (arg == "-cluster"):
                i = i+1;
                if (i < argc):
                        clusterName = sys.argv[i]
                else:
                        argerr = "Missing argument for '" + arg + "' parameter"
                #endElse
        elif (arg == "-zhelp"):
                help = 1
        elif (arg == "-install"):
                display = 0
        elif (arg == "-display"):
                display = 1
        else:
                argerr = "Invalid command line argument: "+arg
        #endElse
        i += 1  #forNext
#endWhile  (#endFor)


if (help):
  print "      '%-25s  " % ( "required argument(s)"+"'" )
  print "           '%-30s  <parameter>   Only in ND" % ( "-cluster"+"'" )
  print "           '%-30s  <parameter>" % ( "-node"+"'" )
  print "           '%-30s  <parameter>" % ( "-server"+"'" )
  print "      '%-25s  " % ( "optional argument(s)"+"'" )
  print "           '%-30s  " % ( "-zhelp" )
  sys.exit()
#endIf

if ( ("argerr" in locals().keys() or "argerr" in globals().keys())  ):
        print argerr
        sys.exit()
#endIf

#
#  Figure out the type of cell (ND or Standalone Server) and build a list
#  of nodes on which to operate.
#
#  Check which type of cell...
#
isnd = AdminTask.isFederated()

if (isnd == 'true'):
    dmNodeName     = java.lang.System.getProperty ( "local.node" )

#------------------------------------------------------------------------------
# Validate all required fields
required = '-server, -node'
if (isnd == 'true') :
  required = required + ', -cluster'
#endif
if ((isnd == 'true' and clusterName == "") or (serverName == "" or nodeName == "")) :
     print "Missing required field(s) " + required
     sys.exit()
#endIf

if ((isnd != 'true' and clusterName != "")) :
     print "Script Needs to be run on Deployment Manager "
     sys.exit()
#endIf



#------------------------------------------------------------------------------
# Audit Arguments

print "--------------------------------------------------------------------------"


print " '-%-26s   <%-35s" % ("cluster'", clusterName+">")
print " '-%-26s   <%-35s" % ("node'", nodeName+">")
print " '-%-26s   <%-35s" % ("server'", serverName+">")
print " '-%-26s   <%-35s" % ("cell'", cellName+">")
print " '-%-26s   <%-35s" % ("ND'", isnd+">")

if (display):
        print " '-display'        <DisplayOnly>      "
#endIf

print "--------------------------------------------------------------------------"

# Use Environment Variables defined at the Cell. Replicated value fro DE is not correct
delscope ="/Node:"+nodeName+"/"
deleteProperty( 'DB2UNIVERSAL_JDBC_DRIVER_PATH' , delscope)
deleteProperty( 'DB2UNIVERSAL_JDBC_DRIVER_NATIVEPATH' , delscope)

# Modify 100Custom.xml to use WAS work manager
modify100CustomXML()


if (display == 0):
  print "--------------------------------------------------------------------------"
  print "Saving Configuration"
  AdminConfig.save( )
  if (sync == 1 ):
      syncNodes()
  #endIf
#endIf

#Done

